<?php
namespace Flex_Divi\Apps;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Helper{

    public static function get_template( $template_name = '', $dir_path = '', $args = [] ) {
		if ( ! $dir_path ) {
			$dir_path = FLEX_DIVI_PATH . "includes/templates/";
		}
        
		$file_path = "{$dir_path}{$template_name}.php";
		if ( ! file_exists( $file_path ) ) {
			$file_path = FLEX_DIVI_PATH . "templates/{$dir_path}{$template_name}.php";
			if ( ! file_exists( $file_path ) ) {
				return esc_html__( "No Template Found", 'flex-divi' );
			}
		}

		if ( ! empty( $args ) ) {
			extract( $args );
		}
		ob_start();
		include_once $file_path;

		return ob_get_clean();
	}
   
    public static function insert_form_data( $data ){

        if ( isset( $_POST[ FLEX_DIVI_PREFIX . '-form-id' ] ) ) {
            return;
        }

        // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
        $nonce_action = FLEX_DIVI_PREFIX . wp_unslash( $_POST[ FLEX_DIVI_PREFIX . '-form-id' ] );
        if( ! wp_verify_nonce( $data['_wpnonce'] , sanitize_text_field( $nonce_action ) ) ){
            return;
        }
        global $wpdb;

        $form_id_key    = FLEX_DIVI_PREFIX . '-form-id';
        $form_name_key  = FLEX_DIVI_PREFIX . '-form-name';
        $form_table     = $wpdb->prefix . FLEX_DIVI_PREFIX . '_forms';
        $entries_table  = $wpdb->prefix . FLEX_DIVI_PREFIX . '_forms_entries';
        $form_name      = isset( $_POST[ $form_name_key ] ) ?? sanitize_text_field( wp_unslash( $_POST[ $form_name_key ] ) );
        $form_unique_id = isset( $_POST[ $form_id_key ] ) ?? sanitize_text_field( wp_unslash( $_POST[ $form_id_key ] ) );
        $form_name      = str_replace( [ FLEX_DIVI_PREFIX . '-form-', '_'], [ '', ' ' ], $form_name );

        unset( $_POST[ $form_name_key ], $_POST[ $form_id_key ], $_POST['_wpnonce'], $_POST['_wp_http_referer'] );

        $entry_data = base64_encode( wp_json_encode( $_POST ) );
        
        $form_exists = $wpdb->get_var($wpdb->prepare(
            "SELECT id FROM %s WHERE form_id = %s",
            $form_table,
            $form_unique_id
        ));

        if ( ! $form_exists ) {
            $wpdb->insert( $form_table,
                [
                    'form_name' => $form_name,
                    'form_id'   => $form_unique_id
                ], [ '%s', '%s' ]
            );
    
            $form_id = $wpdb->insert_id;
        } else {
            $form_id = $form_exists;
        }
    
        $wpdb->insert( $entries_table,
            [
                'form_id'      => $form_id,
                'form_entries' => $entry_data
            ], [ '%d', '%s' ]
        );
    }

    public static function render_icon( $icon, $class = '', $icon_size = '', $type = 'etmodules' ){

        $size = $icon_size ? 'font-size: '. esc_attr( $icon_size ) .'px;' : '';
        $icon_html = sprintf( 
            '<span class="%1$s" style="font-family: ETmodules!important;%2$s">%3$s</span>',
            esc_attr( $class ),
            $size,
            et_pb_process_font_icon( $icon )
        );

        return $icon_html;
    }

    public static function manage_dimension( $row_value, $for = ''){
        if( '' === $row_value ) return '';

        $row_value = explode( '|', $row_value );

        $new_value = $row_value[0] ? $row_value[0] : '0px';
        $new_value .= $row_value[1] ? ' ' . $row_value[1] : ' 0px';
        $new_value .= $row_value[2] ? ' ' . $row_value[2] : ' 0px';
        $new_value .= $row_value[3] ? ' ' . $row_value[3] : ' 0px';

        return $new_value;
    }

    public static function delete_assets( $post_id ){
        $has_css_key = '_' . FLEX_DIVI_PREFIX . '_has_generated_css';
        $raw_css_key = '_' . FLEX_DIVI_PREFIX . '_generated_css_array';
        $css_key = '_' . FLEX_DIVI_PREFIX . '_generated_css';
        if( et_fb_is_enabled( $post_id ) ) {
            delete_post_meta( $post_id, $has_css_key );
            delete_post_meta( $post_id, $raw_css_key );
            delete_post_meta( $post_id, $css_key );
        }
    }

    public static function manage_assets( $post_id, $styles, $settings = [] ){
        $has_css_key = '_' . FLEX_DIVI_PREFIX . '_has_generated_css';
        $css_meta_key = '_' . FLEX_DIVI_PREFIX . '_generated_css_array';
        $has_asset = get_post_meta( $post_id, $has_css_key, true );

        if( $has_asset || empty( $settings ) ) {
            return;
        }

        $css_meta = get_post_meta( $post_id, $css_meta_key, true );
        $css_meta = $css_meta ? $css_meta : [];
        
        $module_id = $settings['_unique_id'];
        $sticky_id = $settings['sticky_id'];
        $css_meta[ $module_id ][ $sticky_id ] = $styles;

        update_post_meta( $post_id, $css_meta_key, $css_meta );
    }

    public static function minify_css($css) {
        // Remove comments
        $css = preg_replace('!/\*.*?\*/!s', '', $css);
        // Remove space after colons
        $css = preg_replace('/\s*:\s*/', ':', $css);
        // Remove whitespace
        $css = preg_replace('/\s*{\s*/', '{', $css);
        $css = preg_replace('/\s*}\s*/', '}', $css);
        $css = preg_replace('/\s*;\s*/', ';', $css);
        // Remove unnecessary semicolons
        $css = preg_replace('/;}/', '}', $css);
        // Remove newlines, tabs, etc.
        $css = preg_replace('/\s+/', ' ', $css);
        
        return trim($css);
    }
}