<?php
namespace Flex_Divi\Apps;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Settings{
    public function __construct() {
		add_action( 'admin_enqueue_scripts', [$this, 'enqueue_scripts' ] );
        add_action( 'admin_menu', [ $this, 'settigs_admin_menu' ] );
        add_action('wp_ajax_flex_divi_delete_form_entry', [ $this, 'delete_form_entry' ]);

    }

    public function enqueue_scripts(){
		$min = FLEX_DIVI_DEV_MODE ? '' : '';
        $localize = [
			'ajax_url' => admin_url('admin-ajax.php'),
            '_nonce'  => wp_create_nonce( FLEX_DIVI_PREFIX ),
            'message' => [
                'confirm_delete' => esc_html__( 'Are you sure you want to delete this entry?', 'flex-divi' )
            ]
		];
		wp_enqueue_style( FLEX_DIVI_PREFIX.'-settings', FLEX_DIVI_ASSET_DIR . "css/settings{$min}.css", array(), FLEX_DIVI_VERSION );
		wp_enqueue_script( FLEX_DIVI_PREFIX.'-settings', FLEX_DIVI_ASSET_DIR . "js/settings{$min}.js", ['jquery'], FLEX_DIVI_VERSION , true );
		wp_localize_script( FLEX_DIVI_PREFIX.'-settings', 'FLEX_DIVI_SETTINGS', $localize );
	}

    public function settigs_admin_menu(){
        add_menu_page(
            esc_html__( 'Flex Divi', 'flex-divi' ),
            esc_html__( 'Flex Divi', 'flex-divi' ),
            'manage_options',
            FLEX_DIVI_PREFIX,
            [ $this, 'display_form_entries' ],
            'dashicons-art',
        );

        // Form Entries Menu
        // add_submenu_page(
        //     FLEX_DIVI_PREFIX,
        //     esc_html__( 'Form Entries', 'flex-divi' ),
        //     esc_html__( 'Form Entries', 'flex-divi' ),
        //     'manage_options',
        //     FLEX_DIVI_PREFIX . '-form-entries',
        //     [ $this, 'display_form_entries' ]
        // );
    }

    public function flex_divi_callback() {
        echo '<h1>Flex Divi</h1>';
    }

    public function display_form_entries(){
        echo '<div class="wrap">';
        $template_name = 'form-list';

        // phpcs:ignore WordPress.Security.NonceVerification.Recommended
        if( isset( $_GET['form'] ) && '' !== $_GET['form'] ){
            $template_name = 'form-entries';
        }

        // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        echo Helper::get_template( $template_name );
        echo '</div>';
    }

    public function delete_form_entry(){
        check_ajax_referer(FLEX_DIVI_PREFIX, 'security');

        $response = [ 'status' => 0, 'message' => __( 'Invalid entry ID', 'flex-divi' ) ];
        if( ! isset( $_POST['entry_id' ] ) ){
            wp_send_json( $response );
        }
        global $wpdb;
        $entry_id = intval($_POST['entry_id']); // Sanitize the entry ID
        if ($entry_id) {
            $entries_table  = $wpdb->prefix . FLEX_DIVI_PREFIX . '_forms_entries';
            $deleted = $wpdb->delete($entries_table, array('id' => $entry_id), array('%d'));

            if ( $deleted ) {
                $response = [ 'status' => 1, 'message' => __( 'Deleted Successfully', 'flex-divi' ) ];
            } else {
                $response['message'] = __( 'Can\'t Delete', 'flex-divi' ); // Send failure response
            }
        }

        wp_send_json( $response );

        wp_die();
    }
    
}