<?php
/*
Plugin Name: Flex Divi
Plugin URI:  https://flexdivi.com
Description: Flex Divi is the ultimate WordPress plugin designed to enhance the functionality of your Divi-based website. It’s a great addon for designers, developers, and site owners who are using Divi Builder. This plugin has powerful tools and features to create stunning and interactive web pages with ease.
Version:     0.0.2
Author:      FlexDev
Author URI:  https://flexdivi.com
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: flex-divi
Domain Path: /languages

Flex Divi is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

Flex Divi is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Flex Divi. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
*/

namespace Flex_Divi;
use Flex_Divi\Apps\Admin;
use Flex_Divi\Apps\Frontend;
use Flex_Divi\Apps\Settings;

define( 'FLEX_DIVI_PREFIX', 'flex_divi' );
define( 'FLEX_DIVI_FILE', __FILE__ );
define( 'FLEX_DIVI_BASENAME', plugin_basename( __FILE__ ) );
define( 'FLEX_DIVI_PATH', trailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'FLEX_DIVI_URL', trailingslashit( plugins_url( '/', __FILE__ ) ) );
define( 'FLEX_DIVI_ASSET_DIR', trailingslashit( plugin_dir_url( __FILE__ ) . 'assets' ) );
define( 'FLEX_DIVI_STYLE_DIR', trailingslashit( plugin_dir_url( __FILE__ ) . 'styles' ) );
define( 'FLEX_DIVI_VERSION', '0.0.1' );
define( 'FLEX_DIVI_DEV_MODE', file_exists( FLEX_DIVI_PATH . '/.git' ) );
define( 'FLEX_DIVI_AUTHOR', 'FlexDev' );
define( 'FLEX_DIVI_AUTHOR_URI', 'https://profiles.wordpress.org/flexdev/' );

class Plugin_Initiator {
	private static $instance = null;

	public function __construct() {
		/**
		 * Including all app files.
		 *
		 * @since 0.0.1
		 */
		$folder_path = plugin_dir_path( __FILE__ ) . 'apps/';
		foreach (glob($folder_path . '*.php') as $file) {
			if ( file_exists( $file ) ) {
				require_once $file;
			}
		}

		if ( is_admin() ) {
			new Admin();
			new Settings();
		} else {
			new Frontend();
		}

		//load text-domain
		load_plugin_textdomain( 'flex-divi', false, dirname( FLEX_DIVI_BASENAME ) . '/languages/' );

		//create table
        register_activation_hook( FLEX_DIVI_FILE, [ $this, 'create_form_table' ] );

		//include divi modules
		add_action( 'divi_extensions_init', [ $this, 'flex_divi_modules_init'] );

	}

	public function create_form_table() {

		global $wpdb;
		$table_name = $wpdb->prefix . FLEX_DIVI_PREFIX . '_forms';
		$table_name_2 = $wpdb->prefix . FLEX_DIVI_PREFIX . '_forms_entries';

		$form_sql = "CREATE TABLE $table_name (
            id INT NOT NULL AUTO_INCREMENT,
            form_id varchar(255) NOT NULL,
            form_name varchar(255) NOT NULL,
            time TIMESTAMP DEFAULT CURRENT_TIMESTAMP, 
            PRIMARY KEY (id)
        )";

		$form_entries_sql = "CREATE TABLE $table_name_2 (
            id INT NOT NULL AUTO_INCREMENT,
            form_id varchar(255) NOT NULL,
            form_entries varchar(255) NOT NULL,
            time TIMESTAMP DEFAULT CURRENT_TIMESTAMP, 
            PRIMARY KEY (id)
        )";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $form_sql );
		dbDelta( $form_entries_sql );
	}

	/**
	 * Creates the extension's main class instance.
	 *
	 * @since 0.0.1
	 */
	public function flex_divi_modules_init() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/flex-divi-modules.php';
	}

	/**
	 * Singleton instance
	 *
	 * @since 0.0.1
	 */
	public static function instance() {
		if ( self::$instance == null ) {
			self::$instance = new self;
		}

		return self::$instance;
	}
}

Plugin_Initiator::instance();
