<?php
use Flex_Divi\Apps\Helper;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Basic Call To Action module (title, content, and button) with FULL builder support
 * This module appears on Visual Builder and requires react component to be provided
 * Due to full builder support, all advanced options (except button options) are added by default
 *
 * @since 1.0.0
 */
class FlexDiviAccordion extends ET_Builder_Module {
	// Module slug (also used as shortcode tag)
	public $slug       = 'flex_divi_accordion';

	// Visual Builder support (off|partial|on)
	public $vb_support = 'on';

	protected $css_wrapper = '%%order_class%% .flex-divi-accordion';

	public $child_slug = 'flex_divi_accordion_item';

	protected $module_credits = array(
		'module_uri' => '',
		'author'     => FLEX_DIVI_AUTHOR,
		'author_uri' => FLEX_DIVI_AUTHOR_URI,
	);

	/**
	 * Module properties initialization
	 *
	 * @since 1.0.0
	 */
	function init() {
		// Module name
		$this->name      = esc_html__( 'Advanced Accordion', 'flex-divi' );
		$this->icon_path = plugin_dir_path( __FILE__ ) . 'icon.svg';

		//enque
		wp_enqueue_style( FLEX_DIVI_PREFIX . '-accordion' );
		wp_enqueue_script( FLEX_DIVI_PREFIX . '-accordion' );

		$this->_use_unique_id = true;

		// Toggle settings
		$this->settings_modal_toggles  = array(
			'general'  => array(
				'toggles' => array(
					'main_content' => esc_html__( 'Content', 'flex-divi' ),
				),
			),
			'advanced'  => array(
				'toggles' => array(
					'accordion_item'    => esc_html__( 'Item', 'flex-divi' ),
					'accordion_heading' => esc_html__( 'Heading', 'flex-divi' ),
					'accordion_icon'    => esc_html__( 'Icon', 'flex-divi' ),
					'accordion_content' => esc_html__( 'Content', 'flex-divi' ),
				),
			),
		);

		Helper::delete_assets( $this->get_current_post_id() );
	}

	/**
	 * Module's specific fields
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_fields() {
		$fields = [
			'heading_background' => array(
				'label'           => esc_html__( 'Background', 'flex-divi' ),
				'type'            => 'color-alpha',
				'tab_slug'        => 'advanced',
				'toggle_slug'     => 'accordion_heading',
			),
			'heading_padding' => array(
				'label'           => esc_html__( 'Padding', 'flex-divi' ),
				'type'            => 'custom_margin',
				'tab_slug'        => 'advanced',
				'toggle_slug'     => 'accordion_heading',
			),

			//icon custom css
			'icon_color' => array(
				'label'           => esc_html__( 'Color', 'flex-divi' ),
				'type'            => 'color-alpha',
				'tab_slug'        => 'advanced',
				'toggle_slug'     => 'accordion_icon',
			),
			'icon_size' => [
				'label'           => esc_html__( 'Icon Size (px)', 'flex-divi' ),
				'type'            => 'range',
				'tab_slug'        => 'advanced',
				'toggle_slug'     => 'accordion_icon',
			],
			'icon_space' => [
				'label'           => esc_html__( 'Space with title (px)', 'flex-divi' ),
				'type'            => 'range',
				'tab_slug'        => 'advanced',
				'toggle_slug'     => 'accordion_icon',
			],

		];

		return $fields;
	}

	/**
	 * Module's advanced options configuration
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_advanced_fields_config() {
		$advanced_fields['animation']    = false;
		$advanced_fields['transform']    = false;
		$advanced_fields['filters']      = false;
		$advanced_fields['text']         = false;
		$advanced_fields['link_options'] = false;
		$advanced_fields['max_width']    = false;


		$advanced_fields['borders']['accordion_item'] = [
            'css'          => [
                'main'      => [
                    'border_radii'  => "{$this->css_wrapper} .flex-divi-accordion-item",
                    'border_styles' => "{$this->css_wrapper} .flex-divi-accordion-item",
                ],
                'important' => 'all',
            ],
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'accordion_item',
        ];

		$advanced_fields['fonts']['accordion_heading'] = [
			'label'          => '',
			'css'            => array(
				'main' => "{$this->css_wrapper} .flex-divi-accordion-item .flex-divi-accordion-item-title",
			),
			'text_align' => false,
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'accordion_heading',
		];

		$advanced_fields['fonts']['accordion_content'] = [
			'label'          => '',
			'css'            => array(
				'main' => "{$this->css_wrapper} .flex-divi-accordion-item .flex-divi-accordion-item-content",
			),
			'text_align' => false,
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'accordion_content',
		];

		$advanced_fields['margin_padding'] = [
            'css'          => [
                'main'      => "{$this->css_wrapper} .flex-divi-accordion-item .flex-divi-accordion-item-content",
                'important' => 'all',
            ],
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'accordion_content',
        ];

		return $advanced_fields;
	}

    public function add_new_child_text() {
		return esc_html__( 'Add New Accordion Item', 'flex-divi' );
	}

    function predefined_child_modules() {
		$output = sprintf(
			'[flex_divi_accordion_item title="Accordion 1" /][flex_divi_accordion_item title="Accordion 2" /]',
			esc_attr__( 'Name', 'flex-divi' ),
			esc_attr__( 'Email Address', 'flex-divi' ),
			esc_attr__( 'Message', 'flex-divi' )
		);

		return $output;
	}

	public function generate_custom_css( $render_slug ){
		$heading_background = $this->props['heading_background'];
		$heading_background = $heading_background ? "background: {$heading_background};" : '';
		$heading_padding = $this->props['heading_padding'];
		$title_padding = Helper::manage_dimension( $heading_padding );
        $title_padding = $title_padding ? "padding:{$title_padding};" : '';
		$section_id = $this->get_sticky_id( $render_slug );
		$wrapper_class = "{$section_id} .flex-divi-accordion";

		$css_rules = "{$heading_background}{$title_padding}";
		$styles = $css_rules ? ".{$wrapper_class} .flex-divi-accordion-item-title{
				{$css_rules}
			}" : '';

		$icon_color = $this->props['icon_color'];
		$icon_color = $icon_color ? "color   : {$icon_color};" : '';
		$icon_size  = $this->props['icon_size'];
		$icon_size  = $icon_size ? "font-size: {$icon_size}px;": '';
		$icon_space = $this->props['icon_space'];
		$icon_space = $icon_space ? "margin-right: {$icon_space}px;" : '';

		$css_rules = "{$icon_color}{$icon_size}{$icon_space}";
		$styles .= $css_rules ? ".{$wrapper_class} .flex-divi-accordion-item-title .fda-icon{
			{$css_rules}
		}" : '';

		return $styles;
	}

	/**
	 * Render module output
	 *
	 * @since 1.0.0
	 *
	 * @param array  $attrs       List of unprocessed attributes
	 * @param string $content     Content being processed
	 * @param string $render_slug Slug of module that is used for rendering output
	 *
	 * @return string module's rendered output
	 */
	function render( $attrs, $content = null, $render_slug ) {
		$settings = $this->props;
		$settings['sticky_id'] = $this->get_sticky_id( $render_slug );
		Helper::manage_assets( $this->get_current_post_id(), $this->generate_custom_css( $render_slug ), $settings );
		return sprintf( '<div class="flex-divi-accordion">%1$s</div>', et_core_sanitized_previously( $this->content ) );
	}
}

new FlexDiviAccordion;
