<?php
use Flex_Divi\Apps\Helper;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Basic Call To Action module (title, content, and button) with FULL builder support
 * This module appears on Visual Builder and requires react component to be provided
 * Due to full builder support, all advanced options (except button options) are added by default
 *
 * @since 1.0.0
 */
class FlexDiviAccordionItem extends ET_Builder_Module {
	// Module slug (also used as shortcode tag)
	public $slug                     = 'flex_divi_accordion_item';
	public $vb_support               = 'on';
	public $type                     = 'child';
	public $child_title_var          = 'title';
	public $child_title_fallback_var = 'title';

	protected $module_credits = array(
		'module_uri' => '',
		'author'     => FLEX_DIVI_AUTHOR,
		'author_uri' => FLEX_DIVI_AUTHOR_URI,
	);

	/**
	 * Module properties initialization
	 *
	 * @since 1.0.0
	 */
	function init() {
		// Module name
		$this->name             = esc_html__( 'Item', 'flex-divi' );

		// Module Icon
		// Load customized svg icon and use it on builder as module icon. If you don't have svg icon, you can use
		// $this->icon for using etbuilder font-icon. (See CustomCta / DICM_CTA class)
		$this->icon_path        =  plugin_dir_path( __FILE__ ) . 'icon.svg';

		// Toggle settings
		$this->settings_modal_toggles  = array(
			'general'  => array(
				'toggles' => array(
					'content_settings' => esc_html__( 'Content', 'flex-divi' ),
				),
			),
			'advanced'  => [
				'toggles' => [
					'max_width' => esc_html__( 'Width', 'flex-divi' )
				]
			],
		);
	}

	/**
	 * Module's specific fields
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_fields() {
		$fields = array(
			'is_active' => array(
				'label'       => esc_html__( 'Active as Default', 'flex-divi' ),
				'type'        => 'yes_no_button',
				'description' => esc_html__( 'Accordion Title', 'flex-divi' ),
				'options'     => array(
					'on'  => esc_html__( 'On', 'flex-divi' ),
					'off' => esc_html__( 'Off', 'flex-divi' ),
				),
				'option_category' => 'basic_option',
				'toggle_slug'     => 'content_settings',
			),
			'title' => array(
				'label'           => esc_html__( 'Title', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Accordion Title', 'flex-divi' ),
				'toggle_slug'     => 'content_settings',
			),
			'acc_content' => array(
				'label'           => esc_html__( 'Content', 'flex-divi' ),
				'type'            => 'tiny_mce',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Content entered here will appear inside the accordion.', 'flex-divi' ),
				'toggle_slug'     => 'content_settings',
			),
			'open_icon' => array(
				'label'               => esc_html__( 'Icon for Open', 'flex-divi' ),
				'type'                => 'et_font_icon_select',
				'renderer'            => 'et_pb_get_font_icon_list',
				'renderer_with_field' => true,
				'toggle_slug'     => 'content_settings',
				'description'     => esc_html__( 'This icon is visible when its open.', 'flex-divi' ),
			),
			'closed_icon' => array(
				'label'               => esc_html__( 'Icon for Closed', 'flex-divi' ),
				'type'                => 'et_font_icon_select',
				'renderer'            => 'et_pb_get_font_icon_list',
				'renderer_with_field' => true,
				'toggle_slug'     => 'content_settings',
				'description'     => esc_html__( 'This icon is showen when its closed.', 'flex-divi' ),
			),
		);

		return $fields;
	}

	/**
	 * Module's advanced options configuration
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_advanced_fields_config() {

		$advanced_fields['link_options']   = false;
		$advanced_fields['background']     = false;
		$advanced_fields['text']           = false;
		$advanced_fields['fonts']    	   = false;
		$advanced_fields['margin_padding'] = false;
		$advanced_fields['animation']      = false;
		$advanced_fields['transform']      = false;
		$advanced_fields['filters']        = false;
		$advanced_fields['box_shadow']     = false;
		$advanced_fields['borders']        = false;

		$advanced_fields['max_width'] = array(
			'use_max_width'        => false, // default
			'use_min_width'        => false, // default
			'use_module_alignment' => false, // default
		);

		return $advanced_fields;
		
	}

	/**
	 * Render module output
	 *
	 * @since 1.0.0
	 *
	 * @param array  $attrs       List of unprocessed attributes
	 * @param string $content     Content being processed
	 * @param string $render_slug Slug of module that is used for rendering output
	 *
	 * @return string module's rendered output
	 */
	function render( $attrs, $content = null, $render_slug ) {
		// Module specific props added on $this->get_fields()
		$title       = $this->props['title'];
		$content     = $this->props['acc_content'];
		$open_icon   = Helper::render_icon( $this->props['open_icon'], 'fda-icon fda-icon-open' ) ;
		$close_icon  = Helper::render_icon( $this->props['closed_icon'], 'fda-icon fda-icon-close' ) ;
		$is_active   = 'on' === $this->props['is_active'] ? ' active' : '';
		
		return sprintf( 
			'<div class="flex-divi-accordion-item%1$s">
						<div class="flex-divi-accordion-item-title">
							%4$s %5$s %2$s</div>
						<div class="flex-divi-accordion-item-content">%3$s</div>
					</div>',
					esc_attr( $is_active ),
			esc_html( $title ),
			et_core_sanitized_previously( $content ),
			$open_icon,
			$close_icon
		);
	}
}

new FlexDiviAccordionItem;
