<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Basic Call To Action module (title, content, and button) with FULL builder support
 * This module appears on Visual Builder and requires react component to be provided
 * Due to full builder support, all advanced options (except button options) are added by default
 *
 * @since 1.0.0
 */
class FlexDiviFormBuilder extends ET_Builder_Module {
	// Module slug (also used as shortcode tag)
	public $slug       = 'flex_divi_form_builder';

	// Visual Builder support (off|partial|on)
	public $vb_support = 'on';

	protected $css_wrapper = '%%order_class%% .flex-divi-form';

	public $child_slug = 'flex_divi_form_input';

	protected $module_credits = array(
		'module_uri' => '',
		'author'     => FLEX_DIVI_AUTHOR,
		'author_uri' => FLEX_DIVI_AUTHOR_URI,
	);

	/**
	 * Module properties initialization
	 *
	 * @since 1.0.0
	 */
	function init() {
		// Module name
		$this->name             = esc_html__( 'Form Builder', 'flex-divi' );
		wp_enqueue_style( FLEX_DIVI_PREFIX . '-form-builder' );
		// Module Icon
		// Load customized svg icon and use it on builder as module icon. If you don't have svg icon, you can use
		// $this->icon for using etbuilder font-icon. (See CustomCta / DICM_CTA class)
		$this->icon_path        =  plugin_dir_path( __FILE__ ) . 'icon.svg';

		$this->_use_unique_id = true;

		// Toggle settings
		$this->settings_modal_toggles  = array(
			'general'  => array(
				'toggles' => array(
					'main_content' => esc_html__( 'Form Content', 'flex-divi' ),
					'submit_button' => esc_html__( 'Submit Button', 'flex-divi' ),
				),
			),
			'advanced'  => array(
				'toggles' => array(
					'form_input_label_style' => esc_html__( 'Label', 'flex-divi' ),
					'form_input_field_style' => esc_html__( 'Input', 'flex-divi' ),
					'form_section_border' => esc_html__( 'Form Border', 'flex-divi' ),
					'form_submit_button' => esc_html__( 'Submit Button', 'flex-divi' ),
				),
			),
		);
	}

	public function add_new_child_text() {
		return esc_html__( 'Add New Field', 'flex-divi' );
	}

	/**
	 * Module's specific fields
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_fields() {
		return array(
			'title' => array(
				'label'           => esc_html__( 'Form Name', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Form Identifier', 'flex-divi' ),
				'toggle_slug'     => 'main_content',
			),
			'hide_title' => array(
				'label'             => esc_html__( 'Hide Name ?', 'flex-divi' ),
				'type'              => 'yes_no_button',
				'options'           => array(
					'yes'  => esc_html__( 'Yes', 'flex-divi' ),
					'no' => esc_html__( 'No', 'flex-divi' ),
				),
				'option_category' => 'basic_option',
				'toggle_slug'     => 'main_content',
			),
			'button_text' => array(
				'label'           => esc_html__( 'Button Text', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'default'         => esc_html__( 'Submit', 'flex-divi'),
				'description'     => esc_html__( 'Text of submit button', 'flex-divi' ),
				'toggle_slug'     => 'submit_button',
			),
		);
	}

	/**
	 * Module's advanced options configuration
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_advanced_fields_config() {
		$advanced_fields['animation']    = false;
		$advanced_fields['transform']    = false;
		$advanced_fields['filters']      = false;
		$advanced_fields['text']         = false;
		$advanced_fields['link_options'] = false;
		$advanced_fields['max_width']    = false;

		$advanced_fields['fonts']['input_label'] = [
			'label'          => '',
			'css'            => array(
				'main' => "{$this->css_wrapper} .flex-divi-input-group label.flex-divi-form-input-label",
			),
			'text_align' => false,
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'form_input_label_style',
		];

		$advanced_fields['form_field']['input'] = [
            'label'          => '',
			'css'            => [
				'main'        => $this->css_wrapper . ' .flex-divi-input-group .flex-divi-input',
				'font'        => $this->css_wrapper . ' .flex-divi-input-group .flex-divi-input',
				'hover'       => $this->css_wrapper . ' .flex-divi-input-group .flex-divi-input:hover',
				'focus'       => $this->css_wrapper . ' .flex-divi-input-group .flex-divi-input:focus',
				'focus_hover' => $this->css_wrapper . ' .flex-divi-input-group .flex-divi-input:focus:hover',
			],
			'box_shadow'    => array(
				'name' => 'fields',
				'css'  => array(
					'main' => "{$this->css_wrapper} .flex-divi-input-group .flex-divi-input",
				),
			),
			'font_field'    => array(
				'css'            => array(
					'main'      => "{$this->css_wrapper} .flex-divi-input-group .flex-divi-input",
					'important' => 'all',
				),
			),
			'margin_padding' => array(
				'css' => array(
					'main'      => "{$this->css_wrapper} .flex-divi-input-group .flex-divi-input",
					'important' => 'all',
				),
			),
			'border_styles' => false,
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'form_input_field_style',
        ];

		$advanced_fields['borders']['input'] = [
            'css'          => [
                'main'      => [
                    'border_radii'  => '%%order_class%% .flex-divi-input-group .flex-divi-input',
                    'border_styles' => '%%order_class%% .flex-divi-input-group .flex-divi-input',
                ],
                'important' => 'all',
            ],
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'form_input_field_style',
        ];

		$advanced_fields['borders']['form'] = [
            'tab_slug'     => 'advanced',
            'toggle_slug'  => 'form_section_border',
        ];

		$advanced_fields['fonts']['button'] = array(
			'label' => '',
			'css'   => array(
				'main' => "{$this->css_wrapper} .flex-divi-submit",
			),
            'hide_text_align' => true,
			'tab_slug' => 'advanced',
			'toggle_slug' => 'form_submit_button'
		);

		return $advanced_fields;
	}

	/**
	 * Render module output
	 *
	 * @since 1.0.0
	 *
	 * @param array  $attrs       List of unprocessed attributes
	 * @param string $content     Content being processed
	 * @param string $render_slug Slug of module that is used for rendering output
	 *
	 * @return string module's rendered output
	 */
	function render( $attrs, $content = null, $render_slug ) {
		// Module specific props added on $this->get_fields()
		$title    = $this->props['title'];
		$btn_text = $this->props['button_text'];
		$title_html = sprintf( '<h2 class="flex-divi-form-heading">%1$s</h2>', esc_html( $title ) );
		
		if( 'on' === $this->props['hide_title'] ){
			$title_html = '';
		}

		$post_id = $this->get_the_ID();
		$section_id = $this->get_sticky_id( $render_slug );
		$form_name = ! empty( $title ) ? $title : FLEX_DIVI_PREFIX . '-form-' . $section_id;
		$form_id = FLEX_DIVI_PREFIX . '_form_' . base64_encode( $post_id . $form_name . $section_id );

		// 3rd party module with full VB support doesn't need to manually wrap its module. Divi builder
		// has automatically wrapped it
		return sprintf(
			'<form method="post" class="flex-divi-form" action="">
				%1$s
				<div class="flex-divi-inputs">%2$s</div>
				<div class="flex-divi-submit-button-wrapper">
					<button class="flex-divi-submit" type="submit">%3$s</button>
				</div>
				<input type="hidden" name="%4$s-form-name" value="%5$s" />
				<input type="hidden" name="%4$s-form-id" value="%6$s" />
				%7$s
			</form>',
			$title_html,
			et_core_sanitized_previously( $this->content ),
			esc_html( $btn_text ),
			FLEX_DIVI_PREFIX,
			esc_attr( $form_name ),
			esc_attr( $form_id ),
			wp_nonce_field( FLEX_DIVI_PREFIX . $form_id )
		);
	}
}

new FlexDiviFormBuilder;
