<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Basic Call To Action module (title, content, and button) with FULL builder support
 * This module appears on Visual Builder and requires react component to be provided
 * Due to full builder support, all advanced options (except button options) are added by default
 *
 * @since 1.0.0
 */
class FlexDiviFormInput extends ET_Builder_Module {
	// Module slug (also used as shortcode tag)
	public $slug                     = 'flex_divi_form_input';
	public $vb_support               = 'on';
	public $type                     = 'child';
	public $child_title_var          = 'label';
	public $child_title_fallback_var = 'label';

	protected $module_credits = array(
		'module_uri' => '',
		'author'     => FLEX_DIVI_AUTHOR,
		'author_uri' => FLEX_DIVI_AUTHOR_URI,
	);

	/**
	 * Module properties initialization
	 *
	 * @since 1.0.0
	 */
	function init() {
		// Module name
		$this->name             = esc_html__( 'Form Input', 'flex-divi' );

		// Module Icon
		// Load customized svg icon and use it on builder as module icon. If you don't have svg icon, you can use
		// $this->icon for using etbuilder font-icon. (See CustomCta / DICM_CTA class)
		$this->icon_path        =  plugin_dir_path( __FILE__ ) . 'icon.svg';

		// Toggle settings
		$this->settings_modal_toggles  = array(
			'general'  => array(
				'toggles' => array(
					'input_settings' => esc_html__( 'Input Settings', 'flex-divi' ),
				),
			),
			'advanced'  => [
				'toggles' => [
					'max_width' => esc_html__( 'Width', 'flex-divi' )
				]
			],
		);
	}

	/**
	 * Module's specific fields
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_fields() {
		$fields = array(
			'label' => array(
				'label'           => esc_html__( 'Label', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Input Label', 'flex-divi' ),
				'toggle_slug'     => 'input_settings',
			),
			'input_type' => array(
				'label'   => esc_html__( 'Type', 'flex-divi' ),
				'type'    => 'select',
				'options' => array(
					'text'   => esc_html__( 'Text', 'flex-divi' ),
					'email'  => esc_html__( 'Email', 'flex-divi' ),
					'number' => esc_html__( 'Number', 'flex-divi' ),
					'textarea' => esc_html__( 'Textarea', 'flex-divi' ),
				),
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Input type', 'flex-divi' ),
				'toggle_slug'     => 'input_settings',
			),
			'name' => array(
				'label'           => esc_html__( 'Name', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Which name the value submitted', 'flex-divi' ),
				'toggle_slug'     => 'input_settings',
			),
			'placeholder' => array(
				'label'           => esc_html__( 'Placeholder', 'flex-divi' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Placeholder', 'flex-divi' ),
				'toggle_slug'     => 'input_settings',
			),
			'is_required' => array(
				'label'             => esc_html__( 'Required ?', 'flex-divi' ),
				'type'              => 'yes_no_button',
				'options'           => array(
					'yes'  => esc_html__( 'Yes', 'flex-divi' ),
					'no' => esc_html__( 'No', 'flex-divi' ),
				),
				'toggle_slug'     => 'input_settings',
			)
		);

		return $fields;
	}

	/**
	 * Module's advanced options configuration
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function get_advanced_fields_config() {

		$advanced_fields['link_options']   = false;
		$advanced_fields['background']     = false;
		$advanced_fields['text']           = false;
		$advanced_fields['fonts']    	   = false;
		$advanced_fields['margin_padding'] = false;
		$advanced_fields['animation']      = false;
		$advanced_fields['transform']      = false;
		$advanced_fields['filters']        = false;
		$advanced_fields['box_shadow']     = false;
		$advanced_fields['borders']        = false;

		$advanced_fields['max_width'] = array(
			'use_max_width'        => false, // default
			'use_min_width'        => false, // default
			'use_module_alignment' => false, // default
		);

		return $advanced_fields;
		
	}

	/**
	 * Render module output
	 *
	 * @since 1.0.0
	 *
	 * @param array  $attrs       List of unprocessed attributes
	 * @param string $content     Content being processed
	 * @param string $render_slug Slug of module that is used for rendering output
	 *
	 * @return string module's rendered output
	 */
	function render( $attrs, $content = null, $render_slug ) {
		// Module specific props added on $this->get_fields()
		$label       = $this->props['label'];
		$type        = $this->props['input_type'];
		$type        = '' === $type ? 'text' : $type;
		$name        = $this->props['name'];
		$placeholder = $this->props['placeholder'];
		$required    = 'on' === $this->props['is_required'] || 'yes' === $this->props['is_required'] ? 'required' : '';
		
		$input_html = '';
		if( 'textarea' !== $type ) {
			$input_html = sprintf(
				'<input class="flex-divi-input" type="%1$s" name="%2$s" placeholder="%3$s" %4$s/>', 
				esc_html( $type ),
				esc_html( $name ),
				esc_html( $placeholder ) ,
				$required
			);
		} else {
			$input_html = sprintf(
				'<textarea class="flex-divi-input" name="%1$s" placeholder="%2$s" %3$s></textarea>',
				esc_html( $name ),
				esc_html( $placeholder ),
				$required
			);
		}
		
		return sprintf(
			'<div class="flex-divi-input-group">
				<label class="flex-divi-form-input-label">%1$s</label>
				%2$s
			</div>',
			esc_html( $label ),
			$input_html,
		);
	}
}

new FlexDiviFormInput;
